# GitData Lib
Data Wrangling for Everyone.

GitData is an easy to use, fast, scalable, distributed data extraction system
with a rich set of commands that provide ways to gather, manage and query data in
an unusually straightforward way.
